@@ -1,13 +1,12 @@
-/*
-   $Id: RemctlClient.java 1177 2003-10-03 23:14:13Z schemers $
-
-   The java client for a "K5 sysctl" - a service for remote execution of 
-   predefined commands. Access is authenticated via GSSAPI Kerberos 5, 
-   authorized via aclfiles.
-
-   Written by Anton Ushakov <antonu@stanford.edu>
-   Copyright 2002 Board of Trustees, Leland Stanford Jr. University
-
+/*  $Id: RemctlClient.java 2649 2006-07-29 00:32:48Z rra $
+**
+**  The Java client for a service for remote execution of predefined
+**  commands. Access is authenticated via GSS-API Kerberos 5, authorized via
+**  aclfiles.
+**
+**  Written by Anton Ushakov <antonu@stanford.edu>
+**  Copyright 2002 Board of Trustees, Leland Stanford Jr. University
+**  See README for licensing terms.
 */
 
 import javax.security.auth.callback.*;
